pub enum SettlementPolicy {
LatestBlock,
SafeBlock,
FinalizedBlock,
}Expand description
Policy for considering the transactions as settled on Ethereum.
Defines when a transaction should be considered settled on the Ethereum network, determining the security guarantees for the settlement operation.
This matches the latest, safe, and finalized block concepts from
Ethereum clients, exposed over the JSON-RPC API.
Variants
LatestBlock
Transaction is considered settled immediately after the specified number of confirmation blocks.
Security: Vulnerable to chain reorganizations beyond the confirmation count.
SafeBlock
Transaction is considered settled when the containing block has been considered “safe.”
Security: Very strong. Reversing a safe block would require a significant portion of validators to be slashed.
Time: Typically up to ~7 minutes on mainnet. Worst case scenario 12-13 minutes.
FinalizedBlock
Transaction is considered settled only when the containing block has been fully finalized.
Time: Typically between 7-13 minutes on mainnet. Worst case scenario ~19 minutes.