pub struct SettlementTransactionConfig {
pub retry_on_transient_failure: TxRetryPolicy,
pub retry_on_not_included_on_l1: TxRetryPolicy,
pub confirmations: usize,
pub settlement_policy: SettlementPolicy,
pub gas_limit_multiplier_factor: Multiplier,
pub gas_limit_ceiling: U256,
pub max_fee_per_gas_floor: u128,
pub max_fee_per_gas_ceiling: u128,
pub max_fee_per_gas_multiplier_factor: Multiplier,
pub max_priority_fee_per_gas_floor: u128,
pub max_priority_fee_per_gas_ceiling: u128,
pub max_priority_fee_per_gas_multiplier_factor: Multiplier,
}Expand description
The settlement transaction configuration.
Fields
retry_on_transient_failure: TxRetryPolicyRetry policy for the transaction when there is a transient failure.
retry_on_not_included_on_l1: TxRetryPolicyRetry policy for the transaction when it is not included on L1.
confirmations: usizeNumber of block confirmations required for the transaction to resolve a receipt.
settlement_policy: SettlementPolicyFinality level required for the transaction to be considered settled.
gas_limit_multiplier_factor: MultiplierGas limit multiplier factor for the transaction.
The gas is calculated as follows:
gas = estimated_gas * gas_multiplier_factor
gas_limit_ceiling: U256Ceiling for the gas limit for the transaction.
max_fee_per_gas_floor: u128Minimum max_fee_per_gas (in wei) for the transaction.
Can be specified with units: “1gwei”, “0.1eth”, “1000000000wei”.
Used for EIP1559 fee max_fee_per_gas.
max_fee_per_gas_ceiling: u128Maximum max_fee_per_gas (in wei) for the transaction.
Use for EIP1559 max_fee_per_gas.
Can be specified with units: “100gwei”, “0.01eth”, “10000000000wei”
max_fee_per_gas_multiplier_factor: MultiplierIncrease rate for the max_fee_per_gas for each retry attempt.
max_priority_fee_per_gas_floor: u128Minimum max_priority_fee_per_gas (in wei) for the transaction.
Can be specified with units: “1gwei”, “0.1eth”, “1000000000wei”.
Used for EIP1559 fee max_priority_fee_per_gas.
max_priority_fee_per_gas_ceiling: u128Maximum max_priority_fee_per_gas (in wei) for the transaction.
Use for EIP1559 max_priority_fee_per_gas.
Can be specified with units: “100gwei”, “0.01eth”, “10000000000wei”
max_priority_fee_per_gas_multiplier_factor: MultiplierIncrease rate for the max_priority_fee_per_gas for each retry attempt.